@@ -1,19 +1,24 @@
-
-import numpy as np
+from sklearn.metrics import mean_squared_error
+from vip_hci.preproc import (cube_recenter_2dfit, cube_recenter_dft_upsampling,
+                             cube_recenter_satspots, cube_recenter_via_speckles,
+                             cube_recenter_radon, frame_shift, cube_subsample,
+                             cube_correct_nan, approx_stellar_position)
+from vip_hci.var import frame_center
+import vip_hci as vip
+import hciplot
+from astropy.modeling import models
+from astropy.utils.data import download_file
+from .helpers import fixture, np
+import copy
 import matplotlib as mpl
 mpl.use('Agg')
-from astropy.modeling import models
-import hciplot
-import vip_hci as vip
-from vip_hci.preproc import (cube_recenter_2dfit, cube_recenter_dft_upsampling,
-                             cube_recenter_satspots, frame_shift)
-from sklearn.metrics import mean_squared_error
 
 try:
     from IPython.core.display import display, HTML
+
     def html(s):
         display(HTML(s))
-except:
+except BaseException:
     def html(s):
         print(s)
 
@@ -45,6 +50,45 @@ def resource(*args):
         return os.path.join(*args)
 
 
+@fixture(scope="module")
+def get_cube(example_dataset_adi):
+    """
+    Get the ADI sequence from conftest.py.
+
+    Parameters
+    ----------
+    example_dataset_adi : fixture
+        Taken automatically from ``conftest.py``.
+
+    Returns
+    -------
+    dsi : VIP Dataset
+
+    """
+    dsi = copy.copy(example_dataset_adi)
+
+    return dsi
+
+@fixture(scope="module")
+def get_ifs_cube(example_dataset_sdi):
+    """
+    Get the ADI+IFS sequence from conftest.py.
+
+    Parameters
+    ----------
+    example_dataset_sdi : fixture
+        Taken automatically from ``conftest.py``.
+
+    Returns
+    -------
+    dsi : VIP Dataset
+
+    """
+    dsi = copy.copy(example_dataset_sdi)
+
+    return dsi
+
+
 def shift_cube(cube, randax, randay):
     return np.array([frame_shift(cube[i], randay[i], randax[i])
                      for i in range(cube.shape[0])])
@@ -103,7 +147,7 @@ def create_cube_with_satspots(n_frames=6, wh=31, star_fwhm=3, debug=False):
 
 def do_recenter(method, cube, shiftx, shifty, errormsg, mse=1e-2,
                 mse_skip_first=False, n_frames=6, debug=False, **kwargs):
-    #===== shift cube
+    # ===== shift cube
     shifted_cube = shift_cube(cube, shiftx, shifty)
 
     if debug:
@@ -111,12 +155,16 @@ def do_recenter(method, cube, shiftx, shifty, errormsg, mse=1e-2,
             method.__name__,
             ", ".join("{}={}".format(k, v) for k, v in kwargs.items())))
 
-    #===== recentering
+    # ===== recentering
     rec_res = method(shifted_cube, debug=debug, **kwargs)
-    
-    recentered_cube= rec_res[0]
-    unshifty= rec_res[1]
-    unshiftx= rec_res[2]
+
+    recentered_cube = rec_res[0]
+    if method == cube_recenter_via_speckles:
+        unshifty = rec_res[-1]
+        unshiftx = rec_res[-2]
+    else:
+        unshifty = rec_res[1]
+        unshiftx = rec_res[2]
 
     if debug:
         hciplot.plot_frames(cube, title="input cube")
@@ -147,15 +195,15 @@ def do_recenter(method, cube, shiftx, shifty, errormsg, mse=1e-2,
             ]).T, columns=["x", "un-x", "y", "un-y"])
             print("\033[33mshifts:\033[0m")
             display(p)
-        except:
+        except BaseException:
             print("\033[33mcalculated shifts:\033[0m", unshiftx)
             print(" " * 18, unshifty)
             print("\033[33moriginal shifts\033[0m:  ", -shiftx)
             print(" " * 18, -shifty)
-        print("\033[33merrors:\033[0m", mean_squared_error(
-            shiftx, -unshiftx), mean_squared_error(shifty, -unshifty))
+        print("\033[33merrors:\033[0m", mean_squared_error(shiftx, -unshiftx), 
+              mean_squared_error(shifty, -unshifty))
 
-    #===== verify error
+    # ===== verify error
     assert mean_squared_error(shiftx, -unshiftx) < mse, errormsg
     assert mean_squared_error(shifty, -unshifty) < mse, errormsg
 
@@ -172,11 +220,40 @@ def do_recenter(method, cube, shiftx, shifty, errormsg, mse=1e-2,
 #   d88P"Y88b      Y88b.  Y8b.          X88 Y88b.       X88
 #  dP"     "Yb      "Y888  "Y8888   88888P'  "Y888  88888P'
 
+def test_approx_star(debug=False):
+    """
+    tests `approx_stellar_position`. The data cube is generated from a 2D 
+    gaussian (positive case).
+    """
+    global seed
 
+    if debug:
+        html("<h2>===== test_2d =====</h2>")
+
+    method = approx_stellar_position
+    errormsg = 'Error when recentering with approx. stellar position method'
+    n_frames = 6
+
+
+    for model, name in {"gauss": "Gaussian"}.items():
+
+        # ===== odd
+        cube = create_cube_with_gauss2d(shape=(n_frames, 9, 9), mean=4,
+                                        stddev=1)
+        cube += np.random.normal(0, 0.1, cube.shape)
+        cy, cx = frame_center(cube)
+        est_yx = method(cube, fwhm=1)
+        esty = est_yx[:,0]
+        estx = est_yx[:,1]
+        mse = 0.02
+        assert mean_squared_error([cy]*len(esty), esty) < mse, errormsg
+        assert mean_squared_error([cx]*len(estx), estx) < mse, errormsg
+        
+    
 def test_2d(debug=False):
     """
-    tests `cube_recenter_2dfit`. The data cube is generated from a 2D gaussian 
-    (positive case) or a 2D "ring" (difference of two 2D gaussians, negative 
+    tests `cube_recenter_2dfit`. The data cube is generated from a 2D gaussian
+    (positive case) or a 2D "ring" (difference of two 2D gaussians, negative
     case).
     """
     global seed
@@ -193,50 +270,50 @@ def test_2d(debug=False):
 
     for model, name in {"moff": "Moffat", "gauss": "Gaussian"}.items():
 
-        #===== odd
+        # ===== odd
         cube = create_cube_with_gauss2d(shape=(n_frames, 9, 9), mean=4,
                                         stddev=1)
 
-        method_args = dict(fwhm=1, subi_size=5, model=model, verbose=False,
-                           negative=False, full_output=True, plot=False)
+        method_args = dict(fwhm=1, subi_size=5, model=model, verbose=True,
+                           negative=False, full_output=True, plot=True)
         do_recenter(method, cube, randax, randay,
                     errormsg=errormsg.format(name), debug=debug, **method_args)
 
-        #===== even
-        cube = create_cube_with_gauss2d(shape=(n_frames, 10, 10),mean=5,
+        # ===== even
+        cube = create_cube_with_gauss2d(shape=(n_frames, 10, 10), mean=5,
                                         stddev=1)
 
-        method_args = dict(fwhm=1, subi_size=6, model=model, verbose=False,
-                           negative=False, full_output=True, plot=False)
+        method_args = dict(fwhm=1, subi_size=6, model=model, verbose=True,
+                           negative=False, full_output=True, plot=True)
         do_recenter(method, cube, randax, randay,
                     errormsg=errormsg.format(name), debug=debug, **method_args)
 
-        #===== odd negative (ring)
+        # ===== odd negative (ring)
         cube = create_cube_with_gauss2d_ring(shape=(n_frames, 9, 9), mean=4,
                                              stddev_outer=3, stddev_inner=2)
 
-        method_args = dict(fwhm=1, subi_size=5, model=model, verbose=False,
-                           negative=True, full_output=True, plot=False)
+        method_args = dict(fwhm=1, subi_size=5, model=model, verbose=True,
+                           negative=True, full_output=True, plot=True)
         do_recenter(method, cube, randax, randay,
                     errormsg=errormsg.format(name), debug=debug, **method_args)
 
-        #===== even negative (ring)
+        # ===== even negative (ring)
         cube = create_cube_with_gauss2d_ring(shape=(n_frames, 10, 10), mean=5,
                                              stddev_outer=3, stddev_inner=2)
 
-        method_args = dict(fwhm=1, subi_size=6, model=model, verbose=False,
-                           negative=True, full_output=True, plot=False)
+        method_args = dict(fwhm=1, subi_size=6, model=model, verbose=True,
+                           negative=True, full_output=True, plot=True)
         do_recenter(method, cube, randax, randay,
                     errormsg=errormsg.format(name), debug=debug, **method_args)
-
-
+        
+        
 def test_dft(debug=False):
     global seed
     if debug:
         html("<h2>===== test_dft =====</h2>")
 
     method = cube_recenter_dft_upsampling
-    method_args_additional = dict(verbose=True, full_output=True, plot=False)
+    method_args_additional = dict(verbose=True, full_output=True, plot=True)
     errormsg = 'Error when recentering with DFT upsampling method'
     n_frames = 6
 
@@ -246,48 +323,48 @@ def test_dft(debug=False):
     randax[0] = 0  # do not shift first frame
     randay[0] = 0
 
-    #===== odd, subi_size=None
+    # ===== odd, subi_size=None
     size = 9
     mean = size // 2
     cube = create_cube_with_gauss2d(shape=(n_frames, size, size), mean=mean,
                                     stddev=1)
 
-    method_args = dict(center_fr1=(mean,mean), subi_size=None, negative=False,
+    method_args = dict(center_fr1=(mean, mean), subi_size=None, negative=False,
                        **method_args_additional)
     do_recenter(method, cube, randax, randay, errormsg=errormsg,
                 mse_skip_first=True, debug=debug, **method_args)
 
-    #===== even, subi_size
+    # ===== even, subi_size
     size = 10
-    mean = size // 2 #- 0.5 # 0-indexed
+    mean = size // 2  # - 0.5 # 0-indexed
     cube = create_cube_with_gauss2d(shape=(n_frames, size, size), mean=mean,
                                     stddev=1)
 
-    method_args = dict(center_fr1=(mean,mean), subi_size=8, negative=False,
+    method_args = dict(center_fr1=(mean, mean), subi_size=8, negative=False,
                        **method_args_additional)
     do_recenter(method, cube, randax, randay, errormsg=errormsg,
                 mse_skip_first=True, debug=debug, **method_args)
 
-    #===== odd negative (ring), subi_size
+    # ===== odd negative (ring), subi_size
     size = 15
     mean = size // 2
     cube = create_cube_with_gauss2d_ring(shape=(n_frames, size, size),
                                          mean=mean, stddev_outer=3,
                                          stddev_inner=2)
 
-    method_args = dict(center_fr1=(mean,mean), subi_size=12, negative=True,
+    method_args = dict(center_fr1=(mean, mean), subi_size=12, negative=True,
                        **method_args_additional)
     do_recenter(method, cube, randax, randay, errormsg=errormsg,
                 mse_skip_first=True, debug=debug, **method_args)
 
-    #===== even negative (ring), subi_size=None
+    # ===== even negative (ring), subi_size=None
     size = 16
-    mean = size // 2 #- 0.5
+    mean = size // 2  # - 0.5
     cube = create_cube_with_gauss2d_ring(shape=(n_frames, size, size),
                                          mean=mean, stddev_outer=3,
                                          stddev_inner=2)
 
-    method_args = dict(center_fr1=(mean,mean), subi_size=None, negative=True,
+    method_args = dict(center_fr1=(mean, mean), subi_size=None, negative=True,
                        **method_args_additional)
     do_recenter(method, cube, randax, randay, errormsg=errormsg,
                 mse_skip_first=True, debug=debug, **method_args)
@@ -297,7 +374,7 @@ def test_dft_image(debug=False):
     """
     notes:
     ======
-    don't forget to specify `mse_skip_first`, as the shift of the first frame 
+    don't forget to specify `mse_skip_first`, as the shift of the first frame
     does not make sense (provided by the user / determined by *gaussian* fit)
     """
     global seed
@@ -308,19 +385,19 @@ def test_dft_image(debug=False):
     errormsg = 'Error when recentering with DFT upsampling method'
     n_frames = 6
 
-    #===== datacube
+    # ===== datacube
     img = vip.fits.open_fits(resource('naco_betapic_single.fits'))
     cube = np.array([img, ] * n_frames)
 
-    #===== shift
+    # ===== shift
     randax = seed.uniform(-1, 1, size=n_frames)
     randay = seed.uniform(-1, 1, size=n_frames)
     randax[0] = 0  # do not shift first frame
     randay[0] = 0
 
-    #===== recenter
-    method_args = dict(center_fr1=(51,51), subi_size=None, verbose=True,
-                       negative=True, full_output=True, plot=False)
+    # ===== recenter
+    method_args = dict(center_fr1=(51, 51), subi_size=None, verbose=True,
+                       negative=True, full_output=True, plot=True)
     do_recenter(method, cube, randax, randay, errormsg=errormsg,
                 mse_skip_first=True, debug=debug, **method_args)
 
@@ -334,18 +411,18 @@ def test_satspots_image(debug=False):
     errormsg = 'Error when recentering with satellite spots'
     n_frames = 6
 
-    #===== datacube
+    # ===== datacube
     img = vip.fits.open_fits(resource('SPHERE_satspots_centered.fits'))
     cube = np.array([img, ] * n_frames)
 
-    #===== shift
+    # ===== shift
     randax = seed.uniform(-1, 1, size=n_frames)
     randay = seed.uniform(-1, 1, size=n_frames)
 
-    #===== recenter
+    # ===== recenter
     spotcoords = [(41, 109), (109, 109), (41, 41), (109, 41)]  # NW NE SW SE
-    method_args = dict(xy=spotcoords, subi_size=25, plot=False,
-                       full_output=True, verbose=False)
+    method_args = dict(xy=spotcoords, subi_size=25,
+                       full_output=True, verbose=True)
     do_recenter(method, cube, randax, randay, errormsg=errormsg, debug=debug,
                 **method_args)
 
@@ -359,17 +436,77 @@ def test_satspots(debug=False):
     errormsg = 'Error when recentering with satellite spots'
     n_frames = 2
 
-    #===== datacube
+    # ===== datacube
     cube, spotcoords = create_cube_with_satspots(n_frames=n_frames)
 
-    #===== shift
+    # ===== shift
     shift_magnitude = 1
     randax = seed.uniform(-shift_magnitude, 0, size=n_frames)
     randay = seed.uniform(0, shift_magnitude, size=n_frames)
 
-    #===== recenter
-    method_args = dict(xy=spotcoords, subi_size=9, plot=False,
-                       full_output=True, verbose=False)
+    # ===== recenter
+    method_args = dict(xy=spotcoords, subi_size=9, plot=True,
+                       full_output=True, verbose=True)
     do_recenter(method, cube, randax, randay, errormsg=errormsg, debug=debug,
                 **method_args)
 
+
+def test_radon(debug=False):
+    global seed
+    if debug:
+        html("<h2>===== test_radon =====</h2>")
+
+    method = cube_recenter_radon
+    errormsg = 'Error when recentering with Radon transform'
+    n_frames = 1
+
+    # ===== datacube
+    url_prefix = "https://github.com/vortex-exoplanet/VIP_extras/raw/master/datasets"
+
+    f1 = download_file("{}/sphere_ifs_PDS70_cen.fits".format(url_prefix),
+                       cache=True)
+
+    # load fits
+    cube = vip.fits.open_fits(f1)
+
+    # subsample and correct for NaNs
+    cube = cube_subsample(cube, 20) #discard last channels with BKG star bias
+    cube = cube_correct_nan(cube)
+
+    # ===== shift
+    shift_magnitude = 1
+    randax = seed.uniform(-shift_magnitude, 0, size=n_frames)
+    randay = seed.uniform(0, shift_magnitude, size=n_frames)
+
+    # ===== recenter
+    method_args = dict(hsize=1.5, step=0.1, cropsize=131, full_output=True, 
+                       mask_center=30, verbose=True)
+    do_recenter(method, cube, randax, randay, errormsg=errormsg, debug=debug,
+                mse=0.8, **method_args)
+    
+
+def test_speckle_recentering(get_cube, debug=False):
+    global seed
+    if debug:
+        html("<h2>===== test_speckle_recentering =====</h2>")
+
+    method = cube_recenter_via_speckles
+    errormsg = 'Error when recentering via speckles'
+
+    # ===== datacube
+    ds = get_cube
+    n_frames = ds.cube.shape[0]
+
+    # ===== shift
+    randax = np.ones(n_frames)
+    randay = np.ones(n_frames)
+
+    # ===== recenter
+    types = ['gaus', 'ann']
+    
+    for ty in types:
+        method_args = dict(plot=False, full_output=True, fwhm=4.2, fit_type=ty,
+                           recenter_median=True, subframesize=49, imlib='opencv',
+                           interpolation='lanczos4')
+        do_recenter(method, ds.cube, randax, randay, errormsg=errormsg, 
+                    debug=debug, mse=0.04, **method_args)
