@@ -6,7 +6,6 @@ Also functions for cropping cubes.
 """
 
 
-
 __author__ = 'Carlos Alberto Gomez Gonzalez, V. Christiaens'
 __all__ = ['cube_crop_frames',
            'cube_drop_frames',
@@ -132,8 +131,8 @@ def frame_crop(array, size, cenxy=None, force=False, verbose=True):
 
 def frame_pad(array, fac, fillwith=0, loc=0, scale=1, full_output=False):
     """ Pads a frame (2d array) equally on each sides, where the final frame
-    size is set by a multiplicative factor applied to the original size. The 
-    padding is set by fillwith, which can be either a fixed value or white 
+    size is set by a multiplicative factor applied to the original size. The
+    padding is set by fillwith, which can be either a fixed value or white
     noise, characterized by (loc, scale).
     Uses the ``get_square`` function.
 
@@ -145,14 +144,14 @@ def frame_pad(array, fac, fillwith=0, loc=0, scale=1, full_output=False):
         Ratio of the size between padded and input frame.
     fillwith : float or str, optional
         If a float or np.nan: value used for padding.
-        If str, must be 'noise', which will inject white noise, using loc and 
+        If str, must be 'noise', which will inject white noise, using loc and
         scale parameters.
     loc : float, optional
         If padding noise, mean of the white noise.
     scale : float, optional
         If padding noise, standard deviation of the white noise.
     full_output : bool, optional
-        Whether to also return the indices of input frame within the padded 
+        Whether to also return the indices of input frame within the padded
         frame (in addition to padded frame).
 
     Returns
@@ -160,40 +159,40 @@ def frame_pad(array, fac, fillwith=0, loc=0, scale=1, full_output=False):
     array_out : numpy ndarray
         Padded array.
     ori_indices: tuple
-        [returned if full_output=True] Indices of the bottom left and top 
+        [returned if full_output=True] Indices of the bottom left and top
         right vertices of the original image within the padded array:
-        (y0, yN, x0, xN).  
+        (y0, yN, x0, xN).
 
     """
-    
-    if not array.ndim==2:
+
+    if not array.ndim == 2:
         raise TypeError("The input array must be 2d")
-    
-    y,x = array.shape
+
+    y, x = array.shape
     cy_ori, cx_ori = frame_center(array)
     new_y = int(y*fac)
     new_x = int(x*fac)
-    if new_y%2 != y%2:
-        new_y-=1
-    if new_x%2 != x%2:
-        new_x-=1
+    if new_y % 2 != y % 2:
+        new_y -= 1
+    if new_x % 2 != x % 2:
+        new_x -= 1
     if fillwith == 'noise':
-        array_out = np.random.normal(loc=loc, scale=scale, size=(new_y,new_x))
+        array_out = np.random.normal(loc=loc, scale=scale, size=(new_y, new_x))
     else:
-        array_out = np.zeros([new_y,new_x],dtype=array.dtype)
+        array_out = np.zeros([new_y, new_x], dtype=array.dtype)
         array_out[:] = fillwith
     cy, cx = frame_center(array_out)
     y0 = int(cy-cy_ori)
     y1 = int(cy+cy_ori)
-    if new_y%2:
-        y1+=1
+    if new_y % 2:
+        y1 += 1
     x0 = int(cx-cx_ori)
     x1 = int(cx+cx_ori)
-    if new_x%2:
-        x1+=1
-    array_out[y0:y1,x0:x1] = array.copy()
-    ori_indices =  (y0, y1, x0, x1)
-    
+    if new_x % 2:
+        x1 += 1
+    array_out[y0:y1, x0:x1] = array.copy()
+    ori_indices = (y0, y1, x0, x1)
+
     if full_output:
         return array_out, ori_indices
     else:
@@ -267,7 +266,7 @@ def frame_remove_stripes(array):
     lines = np.vstack((lines, array[-50:]))
     mean = lines.mean(axis=0)
     for i in range(array.shape[1]):
-        array[:,i] = array[:,i] - mean[i]
+        array[:, i] = array[:, i] - mean[i]
     return array
 
 
@@ -294,7 +293,7 @@ def cube_correct_nan(cube, neighbor_box=3, min_neighbors=3, verbose=False,
         SINFONI data). The algorithm goes twice faster if this option is
         rightfully set to True.
     nproc: None or int, optional
-        Number of CPUs for multiprocessing (only used for 3D input). If None, 
+        Number of CPUs for multiprocessing (only used for 3D input). If None,
         will automatically set it to half the available number of CPUs.
 
     Returns
@@ -329,7 +328,7 @@ def cube_correct_nan(cube, neighbor_box=3, min_neighbors=3, verbose=False,
         if nproc == 1:
             for zz in range(n_z):
                 obj_tmp[zz], nnanpix = nan_corr_2d(obj_tmp[zz], neighbor_box,
-                                                   min_neighbors, half_res_y, 
+                                                   min_neighbors, half_res_y,
                                                    verbose, True)
                 if verbose:
                     msg = "In channel {}, {} NaN pixels were corrected"
@@ -339,7 +338,7 @@ def cube_correct_nan(cube, neighbor_box=3, min_neighbors=3, verbose=False,
                 msg = "Correcting NaNs in multiprocessing..."
                 print(msg)
             res = pool_map(nproc, nan_corr_2d, iterable(obj_tmp), neighbor_box,
-                           min_neighbors, half_res_y, verbose, False) 
+                           min_neighbors, half_res_y, verbose, False)
             obj_tmp = np.array(res, dtype=object)
 
     if verbose:
@@ -350,7 +349,7 @@ def cube_correct_nan(cube, neighbor_box=3, min_neighbors=3, verbose=False,
 
 def nan_corr_2d(obj_tmp, neighbor_box, min_neighbors, half_res_y, verbose,
                 full_output=True):
-    
+
     n_x = obj_tmp.shape[1]
     n_y = obj_tmp.shape[0]
 
@@ -385,12 +384,12 @@ def nan_corr_2d(obj_tmp, neighbor_box, min_neighbors, half_res_y, verbose,
         return obj_tmp, nnanpix
     else:
         return obj_tmp
-    
+
 
 def approx_stellar_position(cube, fwhm, return_test=False, verbose=False):
-    """Finds the approximate coordinates of the star, assuming it is the 
-    brightest signal in the images. The algorithm can handle images dominated 
-    by noise, since outliers are corrected based on the position of ths star in 
+    """Finds the approximate coordinates of the star, assuming it is the
+    brightest signal in the images. The algorithm can handle images dominated
+    by noise, since outliers are corrected based on the position of ths star in
     other channels.
 
     Parameters
@@ -424,7 +423,8 @@ def approx_stellar_position(cube, fwhm, return_test=False, verbose=False):
         fwhm = np.zeros((n_z))
         fwhm[:] = fwhm_scal
 
-    # 1/ Write a 2-columns array with indices of all max pixel values in the cube
+    # 1/ Write a 2-columns array with indices of all max pixel values in the
+    # cube
     star_tmp_idx = np.zeros([n_z, 2])
     star_approx_idx = np.zeros([n_z, 2])
     test_result = np.ones(n_z)
@@ -465,7 +465,7 @@ def approx_stellar_position(cube, fwhm, return_test=False, verbose=False):
                 inf_neigh = max(0, zz - ii)
                 sup_neigh = min(n_z - 1, zz + ii)
             if test_result[inf_neigh] == 1 and test_result[sup_neigh] == 1:
-                star_approx_idx[zz] = np.floor((star_tmp_idx[sup_neigh] + \
+                star_approx_idx[zz] = np.floor((star_tmp_idx[sup_neigh] +
                                                 star_tmp_idx[inf_neigh]) / 2)
             elif test_result[inf_neigh] == 1:
                 star_approx_idx[zz] = star_tmp_idx[inf_neigh]
