@@ -21,7 +21,7 @@ except ImportError:
     warnings.warn("Opencv python bindings are missing.", ImportWarning)
     no_opencv = True
 
-from scipy.ndimage.interpolation import geometric_transform, zoom
+from scipy.ndimage import geometric_transform, zoom
 from scipy.optimize import minimize
 from ..var import frame_center, get_square
 from .subsampling import cube_collapse
@@ -32,7 +32,7 @@ from .cosmetics import frame_crop
 def cube_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
                        keep_center=False, verbose=True):
     """
-    Resample the frames of a cube with a single scale factor. Can deal with NaN 
+    Resample the frames of a cube with a single scale factor. Can deal with NaN
     values.
 
     Wrapper of ``frame_px_resampling``. Useful when we need to upsample
@@ -52,7 +52,7 @@ def cube_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
         See the documentation of the ``vip_hci.preproc.frame_px_resampling``
         function.
     keep_center: bool, opt
-        If input dimensions are even and the star centered (i.e. on 
+        If input dimensions are even and the star centered (i.e. on
         dim//2, dim//2), whether to keep the star centered after scaling, i.e.
         on (new_dim//2, new_dim//2). For a non-centered input cube, better to
         leave it to False.
@@ -71,7 +71,7 @@ def cube_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
     array_resc = []
     for i in range(array.shape[0]):
         imresc = frame_px_resampling(array[i], scale=scale, imlib=imlib,
-                                     interpolation=interpolation, 
+                                     interpolation=interpolation,
                                      keep_center=keep_center)
         array_resc.append(imresc)
 
@@ -88,12 +88,12 @@ def frame_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
     """
     Resample the pixels of a frame changing the frame size.
     Can deal with NaN values.
-    
+
     If ``scale`` < 1 then the frame is downsampled and if ``scale`` > 1 then its
     pixels are upsampled.
-    
+
     Warning: if imlib is not 'vip-fft', the input size is even and keep_center
-    set to True, an additional interpolation (shifting by (0.5,0.5)px) may 
+    set to True, an additional interpolation (shifting by (0.5,0.5)px) may
     occur after rescaling, to ensure center location stays on (dim//2,dim//2).
 
     Parameters
@@ -104,8 +104,8 @@ def frame_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
         Scale factor for upsampling or downsampling the frame. If a tuple it
         corresponds to the scale along x and y.
     imlib : {'ndimage', 'opencv', 'vip-fft'}, optional
-        Library used for image transformations. 'vip-fft' corresponds to a 
-        FFT-based rescaling algorithm implemented in VIP 
+        Library used for image transformations. 'vip-fft' corresponds to a
+        FFT-based rescaling algorithm implemented in VIP
         (``vip_hci.preproc.scale_fft``).
     interpolation : str, optional
         For 'ndimage' library: 'nearneig', bilinear', 'biquadratic', 'bicubic',
@@ -116,7 +116,7 @@ def frame_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
         The 'nearneig' interpolation is the fastest and the 'lanczos4' the
         slowest and accurate.
     keep_center: bool, opt
-        If input dimensions are even and the star centered (i.e. on 
+        If input dimensions are even and the star centered (i.e. on
         dim//2, dim//2), whether to keep the star centered after scaling, i.e.
         on (new_dim//2, new_dim//2). For a non-centered input frame, better to
         leave it to False.
@@ -149,27 +149,27 @@ def frame_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
 
         mask = np.zeros_like(array)
         mask[nan_mask] = 1
-    
-    if array.shape[0]%2:
-        odd=True
+
+    if array.shape[0] % 2:
+        odd = True
     else:
-        odd=False
-            
+        odd = False
+
     # expected output size
-    out_sz = int(round(array.shape[0]*scale_y)), int(round(array.shape[1]*scale_x))
-    
+    out_sz = int(round(array.shape[0]*scale_y)
+                 ), int(round(array.shape[1]*scale_x))
+
     if not odd and keep_center and imlib != 'vip-fft':
         def _make_odd(img):
-            img_odd = np.zeros([img.shape[0]+1,img.shape[1]+1])
-            img_odd[:-1,:-1] = img.copy()
-            img_odd[-1,:-1] = img[-1].copy()
-            img_odd[:-1,-1] = img[:,-1].copy()
-            img_odd[-1,-1] = np.mean([img[-1,-2],img[-2,-1],img[-2,-2]])
+            img_odd = np.zeros([img.shape[0]+1, img.shape[1]+1])
+            img_odd[:-1, :-1] = img.copy()
+            img_odd[-1, :-1] = img[-1].copy()
+            img_odd[:-1, -1] = img[:, -1].copy()
+            img_odd[-1, -1] = np.mean([img[-1, -2], img[-2, -1], img[-2, -2]])
             return img_odd
         array = _make_odd(array)
         if mask is not None:
             mask = _make_odd(mask)
-            
 
     if imlib == 'ndimage':
         if interpolation == 'nearneig':
@@ -192,7 +192,7 @@ def frame_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
         array_resc = zoom(array, zoom=(scale_y, scale_x), order=order)
         # For flux conservation:
         array_resc /= scale_y * scale_x
-        
+
     elif imlib == 'opencv':
         if no_opencv:
             msg = 'Opencv python bindings cannot be imported. Install opencv or'
@@ -209,67 +209,67 @@ def frame_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
             intp = cv2.INTER_LANCZOS4
         else:
             raise TypeError('Opencv interpolation method not recognized')
-            
+
         if mask is not None:
             mask = cv2.resize(mask.astype(np.float32), (0, 0), fx=scale_x,
-                                fy=scale_y, interpolation=intp)
-            
+                              fy=scale_y, interpolation=intp)
+
         array_resc = cv2.resize(array.astype(np.float32), (0, 0), fx=scale_x,
                                 fy=scale_y, interpolation=intp)
-        
+
         # For flux conservation:
         array_resc /= scale_y * scale_x
 
     elif imlib == 'vip-fft':
         if scale_x != scale_y:
-            msg='FFT scaling only supports identical factors along x and y'
+            msg = 'FFT scaling only supports identical factors along x and y'
             raise ValueError(msg)
         if array.shape[0] != array.shape[1]:
-            msg='FFT scaling only supports square input arrays'
-            raise ValueError(msg)   
-            
+            msg = 'FFT scaling only supports square input arrays'
+            raise ValueError(msg)
+
         # make array with even dimensions before FFT-scaling
         if odd:
-            array_even = np.zeros([array.shape[0]+1,array.shape[1]+1])
-            array_even[1:,1:] = array
+            array_even = np.zeros([array.shape[0]+1, array.shape[1]+1])
+            array_even[1:, 1:] = array
             array = array_even
 
         if mask is not None:
             if odd:
-                mask_even = np.zeros([mask.shape[0]+1,mask.shape[1]+1])
-                mask_even[1:,1:] = mask
-                mask = mask_even             
+                mask_even = np.zeros([mask.shape[0]+1, mask.shape[1]+1])
+                mask_even[1:, 1:] = mask
+                mask = mask_even
             mask = scale_fft(mask, scale_x)
             if odd:
-                mask_odd = np.zeros([mask.shape[0]-1,mask.shape[1]-1])
-                mask_odd = mask[1:,1:]
+                mask_odd = np.zeros([mask.shape[0]-1, mask.shape[1]-1])
+                mask_odd = mask[1:, 1:]
                 mask = mask_odd
-            
+
         array_resc = scale_fft(array, scale_x)
         if odd:
-            array = np.zeros([array_resc.shape[0]-1,array_resc.shape[1]-1])
-            array = array_resc[1:,1:]
+            array = np.zeros([array_resc.shape[0]-1, array_resc.shape[1]-1])
+            array = array_resc[1:, 1:]
             array_resc = array
-        
-        #Note: FFT preserves flux - no need to scale flux separately
-        
+
+        # Note: FFT preserves flux - no need to scale flux separately
+
     else:
         raise ValueError('Image transformation library not recognized')
 
     # Place back NaN values in scaled array
     if mask is not None:
         array_resc[mask >= 0.5] = np.nan
- 
-    if keep_center and not array_resc.shape[0]%2 and imlib != 'vip-fft':
+
+    if keep_center and not array_resc.shape[0] % 2 and imlib != 'vip-fft':
         if imlib == 'ndimage':
             imlib_s = 'ndimage-interp'
         else:
             imlib_s = imlib
         array_resc = frame_shift(array_resc, 0.5, 0.5, imlib_s, interpolation)
-        
+
     if array_resc.shape != out_sz and imlib != 'vip-fft':
         if out_sz[0] == out_sz[1]:
-            if out_sz[0]<array_resc.shape[0]:
+            if out_sz[0] < array_resc.shape[0]:
                 array_resc = frame_crop(array_resc, out_sz[0], force=True,
                                         verbose=False)
         else:
@@ -281,8 +281,8 @@ def frame_px_resampling(array, scale, imlib='vip-fft', interpolation='lanczos4',
             wing_x = (out_sz[1]-1)/2
             x0 = int(cx-wing_x)
             xN = int(cx+wing_x+1)
-            array_resc = array_resc[y0:yN,x0:xN]
-            
+            array_resc = array_resc[y0:yN, x0:xN]
+
     if verbose:
         print("Image successfully rescaled")
         print("New shape: {}".format(array_resc.shape))
@@ -324,7 +324,7 @@ def cube_rescaling_wavelengths(cube, scal_list, full_output=True, inverse=False,
        their original size.
     imlib : {'opencv', 'ndimage', 'vip-fft'}, str optional
         Library used for image transformations. Opencv is faster than ndimage or
-        skimage. 'vip-fft' corresponds to a FFT-based rescaling algorithm 
+        skimage. 'vip-fft' corresponds to a FFT-based rescaling algorithm
         implemented in VIP (``vip_hci.preproc.scale_fft``).
     interpolation : str, optional
         For 'ndimage' library: 'nearneig', bilinear', 'bicuadratic', 'bicubic',
@@ -419,7 +419,7 @@ def cube_rescaling_wavelengths(cube, scal_list, full_output=True, inverse=False,
         siz = max(y_in, x_in)
         if frame.shape[0] > siz:
             frame = get_square(frame, siz, cy, cx)
-        if full_output and cube.shape[-1]>siz:
+        if full_output and cube.shape[-1] > siz:
             n_z = cube.shape[0]
             array_old = cube.copy()
             cube = np.zeros([n_z, siz, siz])
@@ -470,8 +470,8 @@ def frame_rescaling(array, ref_xy=None, scale=1.0, imlib='vip-fft',
         Scaling factor. If > 1, it will upsample the input array equally
         along y and x by this factor.
     imlib : {'ndimage', 'opencv', 'vip-fft'}, optional
-        Library used for image transformations. 'vip-fft' corresponds to a 
-        FFT-based rescaling algorithm implemented in VIP 
+        Library used for image transformations. 'vip-fft' corresponds to a
+        FFT-based rescaling algorithm implemented in VIP
         (``vip_hci.preproc.scale_fft``).
     interpolation : str, optional
         For 'ndimage' library: 'nearneig', bilinear', 'biquadratic', 'bicubic',
@@ -508,9 +508,9 @@ def frame_rescaling(array, ref_xy=None, scale=1.0, imlib='vip-fft',
     else:
         if imlib == 'vip-fft' and ref_xy != frame_center(array):
             msg = "'vip-fft'imlib does not yet allow for custom center to be "
-            msg+= " provided "
+            msg += " provided "
             raise ValueError(msg)
-        
+
     # Replace any NaN with real values before scaling
     mask = None
     nan_mask = np.isnan(array)
@@ -520,7 +520,7 @@ def frame_rescaling(array, ref_xy=None, scale=1.0, imlib='vip-fft',
 
         mask = np.zeros_like(array)
         mask[nan_mask] = 1
-        
+
     if imlib == 'ndimage':
         if interpolation == 'nearneig':
             order = 0
@@ -571,36 +571,36 @@ def frame_rescaling(array, ref_xy=None, scale=1.0, imlib='vip-fft',
 
     elif imlib == 'vip-fft':
         if scale_x != scale_y:
-            msg='FFT scaling only supports identical factors along x and y'
+            msg = 'FFT scaling only supports identical factors along x and y'
             raise ValueError(msg)
         if array.shape[0] != array.shape[1]:
-            msg='FFT scaling only supports square input arrays'
-            raise ValueError(msg)   
-            
+            msg = 'FFT scaling only supports square input arrays'
+            raise ValueError(msg)
+
         # make array with even dimensions before FFT-scaling
-        if array.shape[0]%2:
-            odd=True
-            array_even = np.zeros([array.shape[0]+1,array.shape[1]+1])
-            array_even[1:,1:] = array
+        if array.shape[0] % 2:
+            odd = True
+            array_even = np.zeros([array.shape[0]+1, array.shape[1]+1])
+            array_even[1:, 1:] = array
             array = array_even
         else:
             odd = False
 
         if mask is not None:
             if odd:
-                mask_even = np.zeros([mask.shape[0]+1,mask.shape[1]+1])
-                mask_even[1:,1:] = mask
-                mask = mask_even             
+                mask_even = np.zeros([mask.shape[0]+1, mask.shape[1]+1])
+                mask_even[1:, 1:] = mask
+                mask = mask_even
             mask = scale_fft(mask, scale_x, ori_dim=True)
             if odd:
-                mask_odd = np.zeros([mask.shape[0]-1,mask.shape[1]-1])
-                mask_odd = mask[1:,1:]
+                mask_odd = np.zeros([mask.shape[0]-1, mask.shape[1]-1])
+                mask_odd = mask[1:, 1:]
                 mask = mask_odd
-            
+
         array_out = scale_fft(array, scale_x, ori_dim=True)
         if odd:
-            array = np.zeros([array_out.shape[0]-1,array_out.shape[1]-1])
-            array = array_out[1:,1:]
+            array = np.zeros([array_out.shape[0]-1, array_out.shape[1]-1])
+            array = array_out[1:, 1:]
             array_out = array
 
     else:
@@ -610,7 +610,6 @@ def frame_rescaling(array, ref_xy=None, scale=1.0, imlib='vip-fft',
     if mask is not None:
         array_out[mask >= 0.5] = np.nan
 
-    
     return array_out
 
 
@@ -663,8 +662,8 @@ def _cube_resc_wave(array, scaling_list, ref_xy=None, imlib='vip-fft',
 
 def check_scal_vector(scal_vec):
     """
-    Checks that the scaling factor list has the right format (i.e. all factors 
-    >= 1). If not, it returns the vector after normalization by the minimum 
+    Checks that the scaling factor list has the right format (i.e. all factors
+    >= 1). If not, it returns the vector after normalization by the minimum
     value.
 
     Parameters
@@ -691,15 +690,16 @@ def check_scal_vector(scal_vec):
     return scal_vec
 
 
-def find_scal_vector(cube, lbdas, fluxes, mask=None, nfp=2, fm="stddev", 
-                     simplex_options=None, debug=False, **kwargs):
+def find_scal_vector(cube, lbdas, fluxes, mask=None, nfp=2, fm="stddev",
+                     simplex_options=None, debug=False, imlib='vip-fft',
+                     interpolation='lanczos4', **kwargs):
     """
-    Find the optimal scaling factor for the channels of an IFS cube (or of 
+    Find the optimal scaling factor for the channels of an IFS cube (or of
     dual-band pairs of images).
 
     The algorithm finds the optimal scaling factor that minimizes residuals in
-    the rescaled frames. It takes the inverse of the wavelength vector as a 
-    first guess, and uses a similar method as the negative fake companion 
+    the rescaled frames. It takes the inverse of the wavelength vector as a
+    first guess, and uses a similar method as the negative fake companion
     technique, but minimizing residuals in either a mask or the whole field.
 
     Parameters
@@ -709,22 +709,22 @@ def find_scal_vector(cube, lbdas, fluxes, mask=None, nfp=2, fm="stddev",
     lbdas: 1d array or list
         Vector with the wavelengths, used for first guess on scaling factor.
     fluxes: 1d array or list
-        Vector with the (unsaturated) fluxes at the different wavelengths, 
+        Vector with the (unsaturated) fluxes at the different wavelengths,
         used for first guess on flux factor.
     mask: 2D-array, opt
-        Binary mask, with ones where the residual intensities should be 
+        Binary mask, with ones where the residual intensities should be
         evaluated. If None is provided, the whole field is used.
     nfp: int, opt, {1,2}
-        Number of free parameters: spatial scaling alone or spatial scaling + 
+        Number of free parameters: spatial scaling alone or spatial scaling +
         flux scaling.
     fm: str, opt, {"sum","stddev"}
-        Figure of merit to use: sum of squared residuals or stddev of residual 
+        Figure of merit to use: sum of squared residuals or stddev of residual
         pixels.
     options: dict, optional
         The scipy.optimize.minimize options.
     **kwargs: optional
         Optional arguments to the scipy.optimize.minimize function
-        
+
     Returns
     -------
     scal_vec: numpy ndarray, 1d
@@ -747,28 +747,32 @@ def find_scal_vector(cube, lbdas, fluxes, mask=None, nfp=2, fm="stddev",
     flux_vec = np.ones(n_z)
     for z in range(n_z-1):
         flux_scal = fluxes[-1]/fluxes[z]
-        cube_tmp = np.array([cube[z],cube[-1]])
-        if nfp==1:
+        cube_tmp = np.array([cube[z], cube[-1]])
+        if nfp == 1:
             p_ini = (scal_vec_ini[z],)
-            solu = minimize(_chisquare_scal, p_ini, args=(cube_tmp, flux_scal, 
-                                                          mask, fm),
-                            method='Nelder-Mead', options=simplex_options, 
+            solu = minimize(_chisquare_scal, p_ini, args=(cube_tmp, flux_scal,
+                                                          mask, fm, imlib,
+                                                          interpolation),
+                            method='Nelder-Mead', bounds=((1e-1, None),),
+                            options=simplex_options,
                             **kwargs)
             scal_fac, =  solu.x
             flux_fac = flux_scal
         else:
-            p_ini = (scal_vec_ini[z],flux_scal)
-            solu = minimize(_chisquare_scal_2fp, p_ini, args=(cube_tmp,mask,fm),
-                            method='Nelder-Mead', options=simplex_options, 
-                            **kwargs)      
-            scal_fac, flux_fac =  solu.x
+            p_ini = (scal_vec_ini[z], flux_scal)
+            solu = minimize(_chisquare_scal_2fp, p_ini, args=(cube_tmp, mask,
+                                                              fm, imlib,
+                                                              interpolation),
+                            method='Nelder-Mead', options=simplex_options,
+                            bounds=((1e-1, None), (1e-2, None)), **kwargs)
+            scal_fac, flux_fac = solu.x
         if debug:
             print("channel {:.0f}:".format(z), solu.x)
         scal_vec[z] = scal_fac
         flux_vec[z] = flux_fac
 
     scal_vec = check_scal_vector(scal_vec)
-    
+
     return scal_vec, flux_vec
 
 
@@ -785,7 +789,7 @@ def _find_indices_sdi(scal, dist, index_ref, fwhm, delta_sep=1, nframes=None,
     dist : float
         Separation or distance (in pixels) from the center of the array.
     index_ref : int
-        The spectral channel index for which we are finding the indices of 
+        The spectral channel index for which we are finding the indices of
         suitable spectral channels for the model PSF.
     fwhm : float
         Mean FWHM of all the wavelengths (in pixels).
@@ -842,112 +846,114 @@ def _find_indices_sdi(scal, dist, index_ref, fwhm, delta_sep=1, nframes=None,
     return indices
 
 
-def _chisquare_scal(modelParameters, cube, flux_fac=1, mask=None, fm='sum'):
+def _chisquare_scal(modelParameters, cube, flux_fac=1, mask=None, fm='sum',
+                    imlib='vip-fft', interpolation='lanczos4'):
     r"""
     Calculate the reduced math:`\chi^2`:
     .. math:: \chi^2_r = \frac{1}{N-3}\sum_{j=1}^{N} |I_j|,
-    where N is the number of pixels in the image (or mask if provided), and 
-    :math:`I_j` the j-th pixel intensity, considering one free parameter: the 
+    where N is the number of pixels in the image (or mask if provided), and
+    :math:`I_j` the j-th pixel intensity, considering one free parameter: the
     physical scaling factor between images of the cube, for a given
     input flux scaling factor.
-    
+
     Parameters
-    ----------    
+    ----------
     modelParameters: tuple
         The model parameters, typically (scal_fac, flux_fac).
     cube: numpy.array
         The cube of fits images expressed as a numpy.array.
-    flux_fac:     
-        
+    flux_fac:
+
     mask: 2D-array, opt
-        Binary mask, with ones where the residual intensities should be 
+        Binary mask, with ones where the residual intensities should be
         evaluated. If None is provided, the whole field is used.
     fm: str, opt, {"sum","stddev"}
-        Figure of merit to use: sum of squared residuals or stddev of residual 
+        Figure of merit to use: sum of squared residuals or stddev of residual
         pixels.
-        
+
     Returns
     -------
     chi: float
         The reduced chi squared.
-        
+
     """
     # rescale in flux and spatially
     array = cube.copy()
     #scale_fac, flux_fac = modelParameters
     scale_fac, = modelParameters
-    array[0]*=flux_fac
-    scaling_list = np.array([scale_fac,1])
-    array = _cube_resc_wave(array, scaling_list)
+    array[0] *= flux_fac
+    scaling_list = np.array([scale_fac, 1])
+    array = _cube_resc_wave(array, scaling_list, imlib=imlib,
+                            interpolation=interpolation)
 
     frame = array[1]-array[0]
     if mask is None:
         mask = np.ones_like(frame)
-    
-    
+
     if fm == 'sum':
-        chi = np.sum(np.power(frame[np.where(mask)],2))
+        chi = np.sum(np.power(frame[np.where(mask)], 2))
     elif fm == 'stddev':
         values = frame[np.where(mask)]
         values = values[values != 0]
         chi = np.std(values)
     else:
         raise RuntimeError('fm choice not recognized.')
-        
+
     return chi
 
-def _chisquare_scal_2fp(modelParameters, cube, mask=None, fm='sum'):
+
+def _chisquare_scal_2fp(modelParameters, cube, mask=None, fm='sum',
+                        imlib='vip-fft', interpolation='lanczos4'):
     r"""
     Calculate the reduced :math:`\chi^2`:
     .. math:: \chi^2_r = \frac{1}{N-3}\sum_{j=1}^{N} |I_j|,
-    where N is the number of pixels within a circular aperture centered on the 
-    first estimate of the planet position, and :math:`I_j` the j-th pixel 
+    where N is the number of pixels within a circular aperture centered on the
+    first estimate of the planet position, and :math:`I_j` the j-th pixel
     intensity. Two free parameters: physical and flux scaling factors.
-    
+
     Parameters
-    ----------    
+    ----------
     modelParameters: tuple
         The model parameters, typically (scal_fac, flux_fac).
     cube: numpy.array
         The cube of fits images expressed as a numpy.array.
     mask: 2D-array, opt
-        Binary mask, with ones where the residual intensities should be 
+        Binary mask, with ones where the residual intensities should be
         evaluated. If None is provided, the whole field is used.
     fm: str, opt, {"sum","stddev"}
-        Figure of merit to use: sum of squared residuals or stddev of residual 
+        Figure of merit to use: sum of squared residuals or stddev of residual
         pixels.
-        
+
     Returns
     -------
     chi: float
         The reduced chi squared.
-        
+
     """
     # rescale in flux and spatially
     array = cube.copy()
     scale_fac, flux_fac = modelParameters
-    array[0]*=flux_fac
-    scaling_list = np.array([scale_fac,1])
-    array = _cube_resc_wave(array, scaling_list)
+    array[0] *= flux_fac
+    scaling_list = np.array([scale_fac, 1])
+    array = _cube_resc_wave(array, scaling_list, imlib=imlib,
+                            interpolation=interpolation)
 
     frame = array[1]-array[0]
     if mask is None:
         mask = np.ones_like(frame)
-    
-    
+
     if fm == 'sum':
-        chi = np.sum(np.power(frame[np.where(mask)],2))
+        chi = np.sum(np.power(frame[np.where(mask)], 2))
     elif fm == 'stddev':
         values = frame[np.where(mask)]
         values = values[values != 0]
         chi = np.std(values)
     else:
         raise RuntimeError('fm choice not recognized.')
-        
+
     return chi
 
 
-    
 def scale_fft(array, scale, ori_dim=False):
     """
     Resample the frames of a cube with a single scale factor using a FFT-based
@@ -962,33 +968,33 @@ def scale_fft(array, scale, ori_dim=False):
         a tuple it corresponds to the scale along x and y.
     ori_dim: bool, opt
         Whether to crop/pad scaled array in order to have the output with the
-        same dimensions as the input array. By default, the x,y dimensions of 
-        the output are the closest integer to scale*dim_input, with the same 
+        same dimensions as the input array. By default, the x,y dimensions of
+        the output are the closest integer to scale*dim_input, with the same
         parity as the input.
-    
+
     Returns
     -------
     array_resc : numpy ndarray
         Output cube with resampled frames.
-    
+
     """
     if scale == 1:
         return array
-    dim = array.shape[0] # even square
+    dim = array.shape[0]  # even square
     dtype = array.dtype.kind
 
     kd_array = np.arange(dim/2 + 1, dtype=int)
-    
-    # scaling factor chosen as *close* as possible to N''/N', where: 
+
+    # scaling factor chosen as *close* as possible to N''/N', where:
     #   N' = N + 2*KD (N': dim after FT)
-    #   N" = N + 2*KF (N'': dim after FT-1 of FT image), 
+    #   N" = N + 2*KF (N'': dim after FT-1 of FT image),
     #   => N" = 2*round(N'*sc/2)
-    #   => KF = (N"-N)/2 = round(N'*sc/2 - N/2) 
+    #   => KF = (N"-N)/2 = round(N'*sc/2 - N/2)
     #         = round(N/2*(sc-1) + KD*sc)
-    # We call yy=N/2*(sc-1) +KD*sc   
+    # We call yy=N/2*(sc-1) +KD*sc
     yy = dim/2 * (scale - 1) + kd_array.astype(float)*scale
-    
-    # We minimize the difference between the `ideal' N" and its closest 
+
+    # We minimize the difference between the `ideal' N" and its closest
     # integer value by minimizing |yy-int(yy)|.
     kf_array = np.round(yy).astype(int)
     tmp = np.abs(yy-kf_array)
@@ -996,7 +1002,7 @@ def scale_fft(array, scale, ori_dim=False):
 
     kd_io = kd_array[imin]
     kf_io = kf_array[imin]
-    
+
     # Extract a part of array and place into dim_p array
     dim_p = int(dim + 2*kd_io)
     tmp = np.zeros((dim_p, dim_p), dtype=dtype)
@@ -1004,16 +1010,16 @@ def scale_fft(array, scale, ori_dim=False):
 
     # Fourier-transform the larger array
     array_f = np.fft.fftshift(np.fft.fft2(tmp))
-    
+
     # Extract a part of, or expand, the FT to dim_pp pixels
     dim_pp = int(dim + 2*kf_io)
-    
+
     if dim_pp > dim_p:
-        tmp = np.zeros((dim_pp, dim_pp), dtype=np.complex)
-        tmp[(dim_pp-dim_p)//2:(dim_pp+dim_p)//2, 
+        tmp = np.zeros((dim_pp, dim_pp), dtype=complex)
+        tmp[(dim_pp-dim_p)//2:(dim_pp+dim_p)//2,
             (dim_pp-dim_p)//2:(dim_pp+dim_p)//2] = array_f
     else:
-        tmp = array_f[kd_io-kf_io:kd_io-kf_io+dim_pp, 
+        tmp = array_f[kd_io-kf_io:kd_io-kf_io+dim_pp,
                       kd_io-kf_io:kd_io-kf_io+dim_pp]
 
     # inverse Fourier-transform the FT
@@ -1023,22 +1029,22 @@ def scale_fft(array, scale, ori_dim=False):
 
     # Extract a part of or expand the scaled image to desired number of pixels
     dim_resc = int(round(scale*dim))
-    if dim_resc>dim and dim_resc%2 != dim%2:
-         dim_resc+=1
-    elif dim_resc<dim and dim_resc%2 != dim%2:
-         dim_resc-=1 # for reversibility
-    
+    if dim_resc > dim and dim_resc % 2 != dim % 2:
+        dim_resc += 1
+    elif dim_resc < dim and dim_resc % 2 != dim % 2:
+        dim_resc -= 1  # for reversibility
+
     if not ori_dim and dim_pp > dim_resc:
         array_resc = array_resc[(dim_pp-dim_resc)//2:(dim_pp+dim_resc)//2,
                                 (dim_pp-dim_resc)//2:(dim_pp+dim_resc)//2]
     elif not ori_dim and dim_pp <= dim_resc:
-        array = np.zeros((dim_resc,dim_resc))
+        array = np.zeros((dim_resc, dim_resc))
         array[(dim_resc-dim_pp)//2:(dim_resc+dim_pp)//2,
               (dim_resc-dim_pp)//2:(dim_resc+dim_pp)//2] = array_resc
         array_resc = array
     elif dim_pp > dim:
         array_resc = array_resc[kf_io:kf_io+dim, kf_io:kf_io+dim]
-    elif dim_pp  <= dim:
+    elif dim_pp <= dim:
         scaled = array*0
         scaled[-kf_io:-kf_io+dim_pp, -kf_io:-kf_io+dim_pp] = array_resc
         array_resc = scaled
