@@ -16,7 +16,7 @@ from matplotlib import pyplot as plt
 try:
     # for skimage version >= '0.16' use skimage.metrics.structural_similarity
     from skimage.metrics import structural_similarity as ssim
-except:
+except BaseException:
     # before skimage version '0.16' use skimage.measure.compare_ssim
     from skimage.measure import compare_ssim as ssim
 from ..var import get_annulus_segments, get_circle
@@ -171,40 +171,39 @@ def cube_distance(array, frame, mode='full', dist='sad', inradius=None,
     return lista
 
 
-
 def spectral_correlation(array, ann_width=2, r_in=1, r_out=None, pl_xy=None,
-                         mask_r=4, fwhm=4, sp_fwhm_guess=3,full_output=False):
-    """ Computes the spectral correlation between (post-processed) IFS frames, 
-    as a function of radius, implemented as Eq. 7 of Greco & Brandt 2017. This 
-    is a crucial step for an unbias fit of a measured IFS spectrum to either 
+                         mask_r=4, fwhm=4, sp_fwhm_guess=3, full_output=False):
+    """ Computes the spectral correlation between (post-processed) IFS frames,
+    as a function of radius, implemented as Eq. 7 of Greco & Brandt 2017. This
+    is a crucial step for an unbias fit of a measured IFS spectrum to either
     synthetic or template spectra.
-    
+
     Parameters
     ----------
     array : numpy ndarray
-        Input cube or 3d array, of dimensions n_ch x n_y x n_x; where n_y and 
+        Input cube or 3d array, of dimensions n_ch x n_y x n_x; where n_y and
         n_x should be odd values (star should be centered on central pixel).
     ann_width : int, optional
-        Width in pixels of the concentric annuli used to compute the spectral 
-        correlation as a function of radial separation. Greco & Brandt 2017 
-        noted no significant differences for annuli between 1 and 3 pixels 
+        Width in pixels of the concentric annuli used to compute the spectral
+        correlation as a function of radial separation. Greco & Brandt 2017
+        noted no significant differences for annuli between 1 and 3 pixels
         width on GPI data.
     r_in: int, optional
         Innermost radius where the spectral correlation starts to be computed.
     r_out: int, optional
-        Outermost radius where the spectral correlation is computed.If left as 
-        None, it will automatically be computed up to the edge of the frame. 
+        Outermost radius where the spectral correlation is computed.If left as
+        None, it will automatically be computed up to the edge of the frame.
     pl_xy: tuple of tuples of 2 floats, optional
         x,y coordiantes of all companions present in the images.
         If provided, a circle centered on the location of each
         companion will be masked out for the spectral correlation computation.
     mask_r: float, optional
-        if pl_xy is provided, this should also be provided. Size of the 
-        aperture around each companion (in terms of fwhm) that is discarded to 
+        if pl_xy is provided, this should also be provided. Size of the
+        aperture around each companion (in terms of fwhm) that is discarded to
         not bias the spectral correlation computation.
     fwhm: float, optional
-        if pl_xy is provided, this should also be provided. By default we  
-        consider a 2FWHM aperture mask around each companion to not bias the 
+        if pl_xy is provided, this should also be provided. By default we
+        consider a 2FWHM aperture mask around each companion to not bias the
         spectral correlation computation.
     sp_fwhm_guess: float, optional
         Initial guess on the spectral FWHM of all channels.
@@ -215,37 +214,38 @@ def spectral_correlation(array, ann_width=2, r_in=1, r_out=None, pl_xy=None,
     Returns
     -------
     sp_corr : numpy ndarray
-        3d array of spectral correlation, as a function of radius with 
+        3d array of spectral correlation, as a function of radius with
         dimensions: n_r x n_ch x n_ch, where n_r = min((n_y-1)/2,(n_x-1)/2)
         Starts at r = 1 (not r=0) px.
     sp_fwhm: numpy ndarray
-        (if full_output is True) 2d array containing the spectral fwhm at each 
+        (if full_output is True) 2d array containing the spectral fwhm at each
         radius, for each spectral channel. Dims: n_r x n_ch
-        
+
     """
 
-    if not isinstance(ann_width,int) or not isinstance(r_in,int):
+    if not isinstance(ann_width, int) or not isinstance(r_in, int):
         raise TypeError("Inputs should be integers")
 
     if array.ndim != 3:
         raise TypeError("Input array should be 3D.")
-        
+
     n_ch, n_y, n_x = array.shape
-    n_r = min((n_y-1)/2.,(n_x-1)/2.)
-    if n_r%1:
+    n_r = min((n_y-1)/2., (n_x-1)/2.)
+    if n_r % 1:
         raise TypeError("Input array y and x dimensions should be odd")
-    
+
     if r_out is None:
         r_out = n_r
 
-    test_rads = np.arange(r_in-1,r_out-1)
+    test_rads = np.arange(r_in-1, r_out-1)
     n_rad = int(np.floor(test_rads.shape[0]/ann_width))
-    
-    #n_rad = int(np.ceil(n_r/ann_width)) # effective number of annuli probed
-    
-    sp_corr = np.zeros([int(n_r),n_ch,n_ch])
+
+    # n_rad = int(np.ceil(n_r/ann_width)) # effective number of annuli probed
+
+    sp_corr = np.zeros([int(n_r), n_ch, n_ch])
     if full_output:
-        sp_fwhm = np.zeros([int(n_r),n_ch])
+        sp_fwhm = np.zeros([int(n_r), n_ch])
+
         def gauss_1fp(x, *p):
             sigma = p[0]*gaussian_fwhm_to_sigma
             return np.exp(-x**2/(2.*sigma**2))
@@ -256,35 +256,42 @@ def spectral_correlation(array, ann_width=2, r_in=1, r_out=None, pl_xy=None,
         for i in range(len(pl_xy)):
             if not isinstance(pl_xy[i], tuple):
                 raise TypeError("Format of companions coordinates incorrect")
-            mask_i = get_circle(mask, radius=mask_r*fwhm, cy=pl_xy[i][1], cx=pl_xy[i][0], mode="mask")
+            mask_i = get_circle(
+                mask,
+                radius=mask_r*fwhm,
+                cy=pl_xy[i][1],
+                cx=pl_xy[i][0],
+                mode="mask")
             mask_final[np.where(mask_i)] = 1
 
     for ann in range(n_rad):
-        inner_radius = r_in+ (ann * ann_width)
+        inner_radius = r_in + (ann * ann_width)
         indices = get_annulus_segments(array[0], inner_radius, ann_width)
         yy = indices[0][0]
         xx = indices[0][1]
-        yy_final = [yy[i] for i in range(len(indices[0][0])) if not mask_final[yy[i],xx[i]]]
-        xx_final = [xx[i] for i in range(len(indices[0][0])) if not mask_final[yy[i],xx[i]]]
+        yy_final = [yy[i] for i in range(
+            len(indices[0][0])) if not mask_final[yy[i], xx[i]]]
+        xx_final = [xx[i] for i in range(
+            len(indices[0][0])) if not mask_final[yy[i], xx[i]]]
         matrix = array[:, yy_final, xx_final]  # shape (z, npx_annsegm)
         for zi in range(n_ch):
             for zj in range(n_ch):
                 num = np.nanmean(matrix[zi]*matrix[zj])
-                denom = np.sqrt(np.nanmean(matrix[zi]*matrix[zi])* \
+                denom = np.sqrt(np.nanmean(matrix[zi]*matrix[zi]) *
                                 np.nanmean(matrix[zj]*matrix[zj]))
-                sp_corr[r_in+ann*ann_width:r_in+(ann+1)*ann_width,zi,zj] = num/denom
+                sp_corr[r_in+ann*ann_width:r_in +
+                        (ann+1)*ann_width, zi, zj] = num/denom
             if full_output:
                 p0 = (sp_fwhm_guess,)
                 x = np.arange(n_ch)-zi
-                y = sp_corr[r_in+ann*ann_width,zi]# norm y
+                y = sp_corr[r_in+ann*ann_width, zi]  # norm y
                 y = y-np.amin(y)
                 y = y/np.amax(y)
                 coeff, var_matrix = curve_fit(gauss_1fp, x, y, p0=p0)
-                sp_fwhm[r_in+ann*ann_width:r_in+(ann+1)*ann_width,zi] = coeff[0]
+                sp_fwhm[r_in+ann*ann_width:r_in +
+                        (ann+1)*ann_width, zi] = coeff[0]
 
-                
     if full_output:
         return sp_corr, sp_fwhm
     else:
         return sp_corr
-    
\ No newline at end of file
